﻿local L = AceLibrary("AceLocale-2.2"):new("Automaton_Summon")
Automaton_Summon = Automaton:NewModule("Summon", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")
local module = Automaton_Summon

L:RegisterTranslations("enUS", function() return {
	["Summon"] = true,
	["Options for accepting summons."] = true,
	["Enabled"] = true,
	["Accept warlock or meeting stone summons automatically."] = true,
	["Delay"] = true,
	["With this option enabled, automatic summons are delayed for 100 seconds."] = true,
	["Accepting summon in 1:40..."] = true,
	["Accepting summon..."] = true,
	["Cancelling summon..."] = true,
	["In combat! Accepting summon after combat ends..."] = true,
	["Left combat. Accepting summon in 10 seconds..."] = true,
	["Summon expired!"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Summon"] = "자동 소환",
	["Options for accepting summons."] = "소환에 관한 옵션을 설정합니다",
	["Enabled"] = "활성화",
	["Accept warlock or meeting stone summons automatically."] = "자동으로 흑마법사 또는 만남의 돌의 소환을 수락합니다.",
	["Delay"] = "지연",
	["With this option enabled, automatic summons are delayed for 100 seconds."] = "이 옵션이 활성화시, 자동 소환을 100초 동안 지연시킵니다.",
	["Accepting summon in 1:40..."] = "소환 수락 1:40...",
	["Accepting summon..."] = "소환 수락...",
	["Cancelling summon..."] = "소환 취소...",
	["In combat! Accepting summon after combat ends..."] = "전투 중! 전투 종료 후 소환을 수락합니다...",
	["Left combat. Accepting summon in 10 seconds..."] = "전투 종료. 10초 후 소환을 수락합니다...",
	["Summon expired!"] = "소환 종료!",
} end)

L:RegisterTranslations("esES", function() return {
	["Summon"] = "Invocaci\195\179n",
	["Options for accepting summons."] = "Opciones para aceptar invocaciones",
	["Enabled"] = "Activado",
	["Accept warlock or meeting stone summons automatically."] = "Acepta las invocaciones de brujos o piedras de encuentro de forma autom\195\161tica",
	["Delay"] = "Retraso",
	["With this option enabled, automatic summons are delayed for 100 seconds."] = "Las invocaciones son retrasadas 100 segundos",
	["Accepting summon in 1:40..."] = "Aceptando invocaci\195\179n en 1:40m...",
	["Accepting summon..."] = "Aceptando invocaci\195\179n...",
	["Cancelling summon..."] = "Cancelling summon...",
	["In combat! Accepting summon after combat ends..."] = "In combat! Accepting summon after combat ends...",
	["Left combat. Accepting summon in 10 seconds..."] = "Left combat. Accepting summon in 10 seconds...",
	["Summon expired!"] = "Summon expired!",
} end)

L:RegisterTranslations("zhTW", function() return {
	["Summon"] = "招喚",
	["Options for accepting summons."] = "自動接受招喚",
	["Enabled"] = "啟用",
	["Accept warlock or meeting stone summons automatically."] = "自動接受招喚",
	["Delay"] = "延遲",
	["With this option enabled, automatic summons are delayed for 100 seconds."] = "啟用後延遲100秒自動接受招喚",
	["With this option enabled, automatic summons are delayed for 100 seconds."] = "啟用後延遲100秒自動接受招喚",
	["Accepting summon in 1:40..."] = "1分40秒後自動接受招喚",
	["Accepting summon..."] = "接受招喚...",
	["Cancelling summon..."] = "Cancelling summon...",
	["In combat! Accepting summon after combat ends..."] = "In combat! Accepting summon after combat ends...",
	["Left combat. Accepting summon in 10 seconds..."] = "Left combat. Accepting summon in 10 seconds...",
	["Summon expired!"] = "Summon expired!",
} end)

module.description = L["Options for accepting summons."]
module.options = {
	delay = {
		type = 'toggle',
		name = L["Delay"],
		desc = L["With this option enabled, automatic summons are delayed for 100 seconds."],
		get = function() return module.db.profile.delay end,
		set = function(v) module.db.profile.delay = v end,
	},
}

function module:OnInitialize()
	self.db = Automaton:AcquireDBNamespace("Summon")
	Automaton:RegisterDefaults("Summon", "profile", {
		disabled = true,
		delay = true,
	})
	Automaton:SetDisabledAsDefault(self, "Summon")
	self:RegisterOptions(self.options)
end

function module:OnEnable()
	self:RegisterEvent("CONFIRM_SUMMON")

	StaticPopupDialogs["CONFIRM_SUMMON"].OnHide = function()
		if Automaton_Summon:IsEventScheduled("Automaton_SummonAccept") then
			Automaton_Summon:CancelScheduledEvent("Automaton_SummonAccept")
			Automaton_Summon:Print(L["Cancelling summon..."])
		end
		if Automaton_Summon:IsEventScheduled("Automaton_SummonTimeout") then
			Automaton_Summon:CancelScheduledEvent("Automaton_SummonTimeout")
		end
	end
end

function module:OnDisable()
	StaticPopupDialogs["CONFIRM_SUMMON"].OnHide = nil
end

function module:Confirm()
	if UnitAffectingCombat("player") then
		self:Print(L["In combat! Accepting summon after combat ends..."])
		self:RegisterEvent("PLAYER_REGEN_ENABLED", "LeaveCombat")
		self:ScheduleEvent("Automaton_SummonTimeout", self.Timeout, GetSummonConfirmTimeLeft(), self)
		return
	end
	if self:IsEventScheduled("Automaton_SummonTimeout") then
		self:CancelScheduledEvent("Automaton_SummonTimeout")
	end
	ConfirmSummon()
	StaticPopup_Hide("CONFIRM_SUMMON")
end

function module:LeaveCombat()
	self:Print(L["Left combat. Accepting summon in 10 seconds..."])
	self:ScheduleEvent("Automaton_SummonAccept", self.Confirm, 10, self)
end

function module:Timeout()
	self:Print(L["Summon expired!"])
	if self:IsEventScheduled("Automaton_SummonAccept") then
		self:CancelScheduledEvent("Automaton_SummonAccept")
	end
	if self:IsEventRegistered("PLAYER_REGEN_ENABLED") then
		self:UnregisterEvent("PLAYER_REGEN_ENABLED")
	end
end

function module:CONFIRM_SUMMON()
	if module.db.profile.delay and not self:IsEventScheduled("Automaton_SummonAccept") then
		self:Print(L["Accepting summon in 1:40..."])
		self:ScheduleEvent("Automaton_SummonAccept", self.Confirm, 100, self)
	elseif not self:IsEventScheduled("Automaton_SummonAccept") then
		self:Print(L["Accepting summon..."])
		self:Confirm()
	end
end